.. _ipydevguide:

IPython Development Guide (source: old IPython wiki)
====================================================

.. attention::
    This is copied verbatim from the old IPython wiki and is currently under development. Much of the information in this part of the development guide is out of date.

IPython does all of its development using GitHub. All of our development
information is hosted on this GitHub wiki. This page indexes all of that
information. Developers interested in getting involved with IPython
development should start here.

.. toctree::
   :maxdepth: 1
   :caption: Core Documents

   github_workflow
   pull_request
   coding_style
   documenting_ipython

.. toctree::
   :maxdepth: 1
   :caption: Lab Meetings

   lab_meetings

.. toctree::
   :maxdepth: 1
   :caption: Development Policies

   closing_prs

.. toctree::
   :maxdepth: 1
   :caption: Other Information

   testing
   less
   releasing
   sphinx_directive
   py3compat
   rest_api
   js_events
   boot2docker
   testing_kernels

A template for new Python files in IPython:
`template.py <./template.py>`__
